==> react-lds-8.7.0.tgz: package/es/components/VisualPicker/VisualPickerLink.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

/* eslint-disable max-len */
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { MediaObject } from '../MediaObject';

var linkIconRenderer = function linkIconRenderer(figure, classes) {
  return React.createElement("div", {
    className: cx([].concat(_toConsumableArray(classes), ['slds-media__figure_fixed-width', 'slds-align_absolute-center', 'slds-m-left_xx-small']))
  }, figure);
};

var VisualPickerLink = function VisualPickerLink(_ref) {
  var className = _ref.className,
      children = _ref.children,
      href = _ref.href,
      icon = _ref.icon,
      title = _ref.title,
      rest = _objectWithoutProperties(_ref, ["className", "children", "href", "icon", "title"]);

  var sldsClasses = ['slds-box', 'slds-box_link', 'slds-box_x-small', className];
  return React.createElement(MediaObject, _extends({}, rest, {
    center: false,
    customTag: "a" // eslint-disable-next-line no-script-url
    ,
    href: href || 'javascript:void(0)',
    bodyClassName: "slds-border_left slds-p-around_small",
    className: cx(sldsClasses),
    figureLeft: icon,
    renderFigureLeft: linkIconRenderer
  }), React.createElement("h2", {
    className: "slds-truncate slds-text-heading_small",
    title: title
  }, title), React.createElement("p", {
    className: "slds-m-top_small"
  }, children));
};

VisualPickerLink.defaultProps = {
  className: null,
  href: null
};
VisualPickerLink.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Optional className applied to `slds-box`
   */
  className: PropTypes.string,

  /**
   * Flow content
   */
  children: PropTypes.node.isRequired,

  /**
   * Link target. If you need to support a routing library, leave empty and apply `onClick`
   */
  href: PropTypes.string,

  /**
   * Icon rendered on the left. May need to have `svgClassName="slds-icon-text-default"` set for icons from the utility sprite
   */
  icon: PropTypes.element.isRequired,

  /**
   * Title renderd as `heading_small`
   */
  title: PropTypes.string.isRequired
} : {};
export default VisualPickerLink;

==> react-lds-9.1.0.tgz: package/es/components/VisualPicker/VisualPickerLink.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

/* eslint-disable max-len */
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { MediaObject } from '../MediaObject';

var linkIconRenderer = function linkIconRenderer(figure, classes) {
  return React.createElement("div", {
    className: cx([].concat(_toConsumableArray(classes), ['slds-media__figure_fixed-width', 'slds-align_absolute-center', 'slds-m-left_xx-small']))
  }, figure);
};

var VisualPickerLink = function VisualPickerLink(_ref) {
  var className = _ref.className,
      children = _ref.children,
      href = _ref.href,
      icon = _ref.icon,
      title = _ref.title,
      rest = _objectWithoutProperties(_ref, ["className", "children", "href", "icon", "title"]);

  var sldsClasses = ['slds-box', 'slds-box_link', 'slds-box_x-small', className];
  return React.createElement(MediaObject, _extends({}, rest, {
    center: false,
    as: "a" // eslint-disable-next-line no-script-url
    ,
    href: href || 'javascript:void(0)',
    bodyClassName: "slds-border_left slds-p-around_small",
    className: cx(sldsClasses),
    figureLeft: icon,
    renderFigureLeft: linkIconRenderer
  }), React.createElement("h2", {
    className: "slds-truncate slds-text-heading_small",
    title: title
  }, title), React.createElement("p", {
    className: "slds-m-top_small"
  }, children));
};

VisualPickerLink.defaultProps = {
  className: null,
  href: null
};
VisualPickerLink.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Optional className applied to `slds-box`
   */
  className: PropTypes.string,

  /**
   * Flow content
   */
  children: PropTypes.node.isRequired,

  /**
   * Link target. If you need to support a routing library, leave empty and apply `onClick`
   */
  href: PropTypes.string,

  /**
   * Icon rendered on the left. May need to have `svgClassName="slds-icon-text-default"` set for icons from the utility sprite
   */
  icon: PropTypes.element.isRequired,

  /**
   * Title renderd as `heading_small`
   */
  title: PropTypes.string.isRequired
} : {};
export default VisualPickerLink;
